# History
* **1.2.0**
    * You can now specify a maximum number of scans to do with the `--max_scans` flag
    * Results printing is now enhanced
    * A sample output file has been added
* **1.1.0**
    * You can now specify which domain to start from _(when doing a full TLD scan)_ by using the -dc flag `-dc <Domain_To_Continue_From>`
    * You can now save the output of a scan into a file by using the `-o <output_file_name>` flag
* **1.0.6**
    * Fixed bug with files
* **1.0.5**
    * Added __main__ file to root directory to prevent error when starting via python3
* **1.0.4**
    * Corrected errors in documentation and git trees
* **1.0.3**
    * Added more documentation
    * New installation instructions
* **1.0.2**
    * Small documentation changes
* **1.0.1**
    * Fixed 'Module not recognised' bug
    * Added start time to beginning of scan process
    * Fixed verbose mode not printing negative results
* **1.0.0**
    * 1.0.0 full package release
